@@ -3,8 +3,8 @@
 # Ingmar Visser, 23-3-2008
 # 
 
-.First.lib <- function(lib, pkg) {
-	require(nnet)
+.First.lib <- function(lib, pkg) { 
+ 	require(nnet)
 }
 
 .Last.lib <- function(libpath) {}
@@ -32,12 +32,18 @@ setGeneric("nresp", function(object, ...) standardGeneric("nresp"))
 
 setGeneric("freepars", function(object, ...) standardGeneric("freepars"))
 
+setGeneric("nlin", function(object, ...) standardGeneric("nlin"))
+
 setGeneric("logLik", function(object, ...) standardGeneric("logLik"))
 
 setGeneric("fit", function(object, ...) standardGeneric("fit"))
 
 setGeneric("posterior", function(object, ...) standardGeneric("posterior"))
 
+setGeneric("forwardbackward", function(object, ...) standardGeneric("forwardbackward"))
+
+setGeneric("simulate", function(object,nsim=1,seed=NULL, ...) standardGeneric("simulate"))
+
 setGeneric("predict", function(object, ...) standardGeneric("predict"))
 
 setGeneric("AIC", function(object, ..., k=2) standardGeneric("AIC"))
@@ -60,3 +66,5 @@ setGeneric("ntimes", function(object, ...) standardGeneric("ntimes"))
 
 setGeneric("nresp", function(object, ...) standardGeneric("nresp"))
 
+setGeneric("is.stationary", function(object,...) standardGeneric("is.stationary"))
+
