@@ -3,7 +3,7 @@ setMethod("fit",
 	signature(object="mix"),
 	function(object,fixed=NULL,equal=NULL,conrows=NULL,conrows.upper=0,conrows.lower=0,method=NULL,...) {
 
-		# when there are linear constraints donlp should be used
+		# when there are constraints donlp should be used
 		# otherwise EM is good
 		
 		# can/does EM deal with fixed constraints??? it should be possible for sure
@@ -30,6 +30,8 @@ setMethod("fit",
 		# set those fixed parameters in the appropriate submodels
 		object <- setpars(object,fixed,which="fixed")
 		
+		if(is.nan(logLik(object))) stop("Initial model infeasible, log likelihood is NaN; please provide better starting values. ")
+		
 		if(method=="EM") {
 			object <- em(object,verbose=TRUE,...)
 		}
@@ -71,20 +73,20 @@ setMethod("fit",
 			if(!is.null(conrows)) {
 				if(ncol(conrows)!=npar(object)) stop("'conrows' does not have the right dimensions")
 				lincon <- rbind(lincon,conrows)
-				if(conrows.upper==0) {
+				if(any(conrows.upper==0)) {
 					lin.u <- c(lin.u,rep(0,nrow(conrows)))
 				} else {
 					if(length(conrows.upper)!=nrow(conrows)) stop("'conrows.upper does not have correct length")
 					lin.u <- c(lin.u,conrows.upper)
 				}
-				if(conrows.lower==0) {
+				if(any(conrows.lower==0)) {
 					lin.l <- c(lin.l,rep(0,nrow(conrows)))
 				} else {
 					if(length(conrows.lower)!=nrow(conrows)) stop("'conrows.lower does not have correct length")
 					lin.l <- c(lin.l,conrows.lower)
 				}
 			}
-						
+				
 			# select only those columns of the constraint matrix that correspond to non-fixed parameters
 			linconFull <- lincon
 			lincon <- lincon[,!fixed,drop=FALSE]
@@ -95,7 +97,7 @@ setMethod("fit",
 			mycontrol <- function(info) {
 				return(TRUE)
 			}
-			
+						
 			# optimize the parameters
 			result <- donlp2(pars,logl,
 				par.upper=par.u,
