@@ -26,14 +26,18 @@ setMethod("freepars","mix.fitted",
 
 setMethod("nlin","mix.fitted",
 	function(object) {
-		nlin <- qr(object@conMat[which(object@lin.lower==object@lin.upper),,drop=FALSE])$rank
+		conMat <- object@conMat[which(object@lin.lower==object@lin.upper),,drop=FALSE]
+		if(nrow(conMat)==0) nlin <- 0 
+		else nlin <- qr(conMat)$rank
 		nlin
 	}
 )
 
 setMethod("nlin","depmix.fitted",
 	function(object) {
-		nlin <- qr(object@conMat[which(object@lin.lower==object@lin.upper),,drop=FALSE])$rank
+		conMat <- object@conMat[which(object@lin.lower==object@lin.upper),,drop=FALSE]
+		if(nrow(conMat)==0) nlin <- 0 
+		else nlin <- qr(conMat)$rank
 		nlin
 	}
 )
