@@ -35,32 +35,26 @@ setMethod("GLMresponse",
 		if(family$family=="binomial") {
 			# FIX ME
 			y <- model.response(mf)
-			switch(is(y)[1],
-				factor = {
-					y <- as.matrix(as.numeric(as.numeric(y)==1))
-					#n <- matrix(1,nrow=nrow(y))
-				},
-				matrix = {
-					if(ncol(y) == 2) {
-						#n <- as.matrix(rowSums(y))
-						#y <- as.matrix(y[,1])
-					} else {
-						stop("model response not valid for binomial model")
-					}
-				},
-				numeric = {
+			if(NCOL(y) == 1) {
+				if(is.factor(y)) y <- as.matrix(as.numeric(as.numeric(y)==1)) else {
+					if(!is.numeric(y)) stop("model response not valid for binomial model")
 					if(sum(y %in% c(0,1)) != length(y)) stop("model response not valid for binomial model")
-					#n <- matrix(1,nrow=length(y))
 					y <- as.matrix(y)
-				},
-				stop("model response not valid for binomial model")
-				# assume 1 success, rest not
-				#y <- as.numeric(as.numeric(y)==1)
-			)
+				}
+			} else {
+				if(ncol(y) != 2) {
+					stop("model response not valid for binomial model")
+				}
+			}
 		}
 		if(family$family=="multinomial") {
 			y <- model.response(mf)
-			if(is.factor(y)) y <- model.matrix(~y-1) else if(is.numeric(y)) y <- model.matrix(~factor(y)-1)
+			if(NCOL(y) == 1) {
+				if(is.factor(y)) y <- model.matrix(~y-1) else {
+					if(!is.numeric(y)) stop("model response not valid for binomial model")
+					y <- model.matrix(~factor(y)-1)
+				}
+			}
 			parameters$coefficients <- matrix(0,ncol=ncol(y),nrow=ncol(x))
 			if(is.null(fixed)) {
 				fixed <- parameters$coefficients
@@ -81,10 +75,17 @@ setMethod("GLMresponse",
 				pstart <- matrix(pstart,ncol(x),byrow=TRUE)
 				if(ncol(x)>1) parameters$coefficients[2:ncol(x),] <- pstart[2:ncol(x),]
 			} else {
-				parameters$coefficients <- family$linkfun(as.numeric(pstart[1:length(parameters$coefficients)]))
-			}
-			if(length(unlist(parameters))>length(parameters$coefficients)) {
-				if(family$family=="gaussian") parameters$sd <- as.numeric(pstart[(length(parameters$coefficients)+1)])
+				# if(prob) parameters$coefficients <- family$linkfun(as.numeric(pstart[1:length(parameters$coefficients)]))
+  			if(family$family=="binomial") {
+  				if(prob) parameters$coefficients[1] <- family$linkfun(pstart[1])
+  				else parameters$coefficients[1] <- pstart[1]
+  				if(ncol(x)>1) parameters$coefficients[2:ncol(x)] <- pstart[2:ncol(x)]
+  			} else {
+          parameters$coefficients[1:ncol(x)] <- pstart[1:ncol(x)]
+  			}
+  			if(length(unlist(parameters))>length(parameters$coefficients)) {
+  				if(family$family=="gaussian") parameters$sd <- as.numeric(pstart[(length(parameters$coefficients)+1)])
+  			}
 			}
 		}
 		mod <- switch(family$family,
@@ -109,9 +110,16 @@ setMethod("show","GLMresponse",
 			# also print probabilities at covariate values of zero
 			cat("Probalities at zero values of the covariates.\n")
 			if(!(is.null(dim(object@parameters$coefficients)))) {
-				cat(object@family$linkinv(object@parameters$coefficients[1,],base=object@family$base),"\n")
+				if(dim(object@parameters$coefficients)[1]>1) {
+					cat(object@family$linkinv(object@parameters$coefficients[1,],base=object@family$base),"\n")
+				} else {
+					cat(object@family$linkinv(object@parameters$coefficients,base=object@family$base),"\n")
+				}
 			} else {
-				cat(object@family$linkinv(object@parameters$coefficients,base=object@family$base),"\n")
+				if(object@family$link=="identity") cat(object@family$linkinv(object@parameters$coefficients),"\n")
+				else {
+					cat(object@family$linkinv(object@parameters$coefficients,base=object@family$base),"\n")
+				}
 			}
 		}
 		if(object@family$family=="binomial") {
@@ -134,16 +142,13 @@ setMethod("setpars","GLMresponse",
 		switch(which,
 			"pars"= {
 				if(object@family$family=="multinomial") {
-					
 					object@parameters$coefficients <- matrix(values,ncol(object@x),byrow=TRUE)
-					
 					if(prob) object@parameters$coefficients[1,] <- object@family$linkfun(values[1:ncol(object@parameters$coefficients)],base=object@family$base)
-					
 # 					object@parameters$coefficients[1,] <- values[1:ncol(object@parameters$coefficients)]
 # 					values <- matrix(values,,ncol(object@x),byrow=TRUE)
 # 					if(ncol(object@x)>1) object@parameters$coefficients[2:ncol(object@x),] <- values[2:ncol(object@x),]
 				} else {
-					object@parameters$coefficients <- values[1:length(object@parameters$coefficients)]
+					object@parameters$coefficients <- values[1:length(object@parameters$coefficients)] # matrix(values,ncol(object@x),byrow=TRUE) # this needs fixing!!!!
 				}
 				if(length(unlist(object@parameters))>length(object@parameters$coefficients)) {
 					if(object@family$family=="gaussian") object@parameters$sd <- as.numeric(values[(length(object@parameters$coefficients)+1)])
