@@ -9,11 +9,12 @@ setMethod("fit","MULTINOMresponse",
 		y <- object@y
 		x <- object@x
 		#if(is.null(w)) w <- rep(1,nrow(y))
+		# mask is an nx*ny matrix (x are inputs, y are output levels)
 		mask <- matrix(1,nrow=nrow(pars$coefficients),ncol=ncol(pars$coefficients))
 		mask[,base] <- 0 # fix base category coefficients to 0
-		mask <- rbind(0,mask) # fix "bias" nodes to 0
+		mask <- rbind(0,mask) # fix automatic "bias" nodes to 0
 		Wts <- mask
-		Wts[-1,] <- t(pars$coefficients) # set starting weights
+		Wts[-1,] <- pars$coefficients # set starting weights
 		if(!is.null(w)) {
 			if(NCOL(y) < 3) {
 				fit <- nnet.default(x,y,weights=w,size=0,entropy=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
@@ -27,7 +28,9 @@ setMethod("fit","MULTINOMresponse",
 				fit <- nnet.default(x,y,size=0,softmax=TRUE,skip=TRUE,mask=mask,Wts=Wts,trace=FALSE)
 			}
 		}
+		# this is necessary because setpars wants coefficients in column major order
 		pars$coefficients <- t(matrix(fit$wts,ncol=ncol(pars$coefficients),nrow=nrow(pars$coefficients)+1)[-1,])
+		# parameters are set correctly now
 		object <- setpars(object,unlist(pars))
 		object
 	}
